<h1 align="center">🤩✨ Emojex 🧠💻</h1>

<p align="center">
    <img src="./.github/pypi.png" />
</p>

<p align="center">
    <img src="https://img.shields.io/pypi/v/emojex?color=3776AB&label=Python%20package%20version&logo=PyPI&logoColor=FFFFFF&style=for-the-badge" />
    <img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dd/emojex?color=98CA3F&label=Downloads&logo=python&logoColor=98CA3F&style=for-the-badge">
</p>

<p align="center">
    Converter of popular culture texts to emoji
</p>


## 🐍 How to use
```bash
pip install emojex
```

## 🤲 Contributing
Do you would like to contribute? Do you want to be the author of a new feature? Awesome! please fork the repository and make changes as you like. [Pull requests](https://github.com/360macky/emojex/pulls) are warmly welcome.


## 📃 License
Distributed under the MIT License.
See [`LICENSE`](./LICENSE) for more information.
